Module wade_quic

Wade QUIC transport layer - UDP socket management and connection dispatch Handles incoming QUIC packets and routes them to appropriate connection processes.

Behaviours: gen_server.

Description

Wade QUIC transport layer - UDP socket management and connection dispatch Handles incoming QUIC packets and routes them to appropriate connection processes.

Function Index

code_change/3
get_connection/1
handle_call/3
handle_cast/2
handle_info/2
init/1
send_packet/3
start_link/2
stop/0
terminate/2

Function Details

code_change/3

code_change(OldVsn, State, Extra) -> any()

get_connection/1

get_connection(ConnID::binary()) -> {ok, pid()} | {error, not_found}

handle_call/3

handle_call(Request, From, State) -> any()

handle_cast/2

handle_cast(Msg, State) -> any()

handle_info/2

handle_info(Info, State) -> any()

init/1

init(X1) -> any()

send_packet/3

send_packet(IP::inet:ip_address(), Port::inet:port_number(), Packet::binary()) -> ok

start_link/2

start_link(Port::integer(), Options::map()) -> {ok, pid()} | {error, term()}

stop/0

stop() -> ok

terminate/2

terminate(Reason, State) -> any()


Generated by EDoc