Module wade_quic_conn

QUIC connection state machine Manages connection lifecycle, packet processing, and stream multiplexing.

Behaviours: gen_statem.

Description

QUIC connection state machine Manages connection lifecycle, packet processing, and stream multiplexing

Function Index

callback_mode/0
close/1
closing/3
code_change/4
create_stream/2
draining/3
established/3
handle_packet/3
handshake/3
init/1
initial/3
send_data/3
start_link/1
terminate/3

Function Details

callback_mode/0

callback_mode() -> any()

close/1

close(Pid::pid()) -> ok

closing/3

closing(EventType, Event, State) -> any()

code_change/4

code_change(OldVsn, StateName, State, Extra) -> any()

create_stream/2

create_stream(Pid::pid(), Type::bidi | uni) -> {ok, integer()} | {error, term()}

draining/3

draining(EventType, Event, State) -> any()

established/3

established(EventType, Event, State) -> any()

handle_packet/3

handle_packet(Pid::pid(), Quic_header::#quic_header{}, Payload::binary()) -> ok

handshake/3

handshake(EventType, Event, State) -> any()

init/1

init(Options) -> any()

initial/3

initial(EventType, Event, State) -> any()

send_data/3

send_data(Pid::pid(), StreamID::integer(), Data::binary()) -> ok | {error, term()}

start_link/1

start_link(Options::map()) -> {ok, pid()} | {error, term()}

terminate/3

terminate(Reason, State, Data) -> any()


Generated by EDoc