Module wade_quic_stream

QUIC stream management Handles individual stream lifecycle, flow control, and data buffering.

Behaviours: gen_server.

Description

QUIC stream management Handles individual stream lifecycle, flow control, and data buffering

Function Index

close/1
code_change/3
handle_call/3
handle_cast/2
handle_frame/2
handle_info/2
init/1
send_data/2
start_link/1
terminate/2
update_max_data/2

Function Details

close/1

close(Pid::pid()) -> ok

code_change/3

code_change(OldVsn, State, Extra) -> any()

handle_call/3

handle_call(Request, From, State) -> any()

handle_cast/2

handle_cast(Msg, State) -> any()

handle_frame/2

handle_frame(Pid::pid(), Stream_frame::#stream_frame{}) -> ok

handle_info/2

handle_info(Info, State) -> any()

init/1

init(Options) -> any()

send_data/2

send_data(Pid::pid(), Data::binary()) -> ok | {error, term()}

start_link/1

start_link(Options::map()) -> {ok, pid()} | {error, term()}

terminate/2

terminate(Reason, State) -> any()

update_max_data/2

update_max_data(Pid::pid(), MaxData::integer()) -> ok


Generated by EDoc