Behaviours: application.
| start/0 | Start Wade with default port 8080. |
| start/1 | Start Wade on a specific port. |
| stop/0 | Stop the Wade server. |
start() -> any()
Equivalent to start(8080).
Start Wade with default port 8080. Ensures all dependencies are started and then starts the Wade supervisor.
start(Port) -> any()
Start Wade on a specific port. Ensures all dependencies are started before starting the Wade supervisor. If Wade is already running, returns {error, already_started}.
stop() -> any()
Stop the Wade server. Terminates the Wade worker child under the supervisor. If Wade is not running, returns {error, not_running}.
Generated by EDoc